# Attend and Excite: Attention-Based Semantic Guidance for Text-to-Image Diffusion Models
文生图功能:给定输入描述，提供图像生成中的文本注意力控制

https://huggingface.co/docs/diffusers/api/pipelines/stable_diffusion/attend_and_excite